@@ -27,7 +27,7 @@
 
 #include "tracker-class.h"
 #include "tracker-namespace.h"
-#include "tracker-ontology.h"
+#include "tracker-ontologies.h"
 
 #define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), TRACKER_TYPE_CLASS, TrackerClassPriv))
 
@@ -37,6 +37,8 @@ struct _TrackerClassPriv {
 	gchar *uri;
 	gchar *name;
 	gint count;
+	gint id;
+	gboolean is_new;
 
 	GArray *super_classes;
 };
@@ -55,7 +57,9 @@ enum {
 	PROP_0,
 	PROP_URI,
 	PROP_NAME,
-	PROP_COUNT
+	PROP_COUNT,
+	PROP_ID,
+	PROP_IS_NEW
 };
 
 G_DEFINE_TYPE (TrackerClass, tracker_class, G_TYPE_OBJECT);
@@ -89,9 +93,25 @@ tracker_class_class_init (TrackerClassClass *klass)
 	                                                   "count",
 	                                                   "Count",
 	                                                   0,
-	                                                   INT_MAX,
+	                                                   G_MAXINT,
+	                                                   0,
+	                                                   G_PARAM_READWRITE));
+	g_object_class_install_property (object_class,
+	                                 PROP_ID,
+	                                 g_param_spec_int ("id",
+	                                                   "id",
+	                                                   "Id",
+	                                                   0,
+	                                                   G_MAXINT,
 	                                                   0,
 	                                                   G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (object_class,
+	                                 PROP_IS_NEW,
+	                                 g_param_spec_boolean ("is-new",
+	                                                       "is-new",
+	                                                       "Is new",
+	                                                       FALSE,
+	                                                       G_PARAM_READWRITE));
 
 	g_type_class_add_private (object_class, sizeof (TrackerClassPriv));
 }
@@ -103,6 +123,7 @@ tracker_class_init (TrackerClass *service)
 
 	priv = GET_PRIV (service);
 
+	priv->id = 0;
 	priv->super_classes = g_array_new (TRUE, TRUE, sizeof (TrackerClass *));
 }
 
@@ -141,6 +162,12 @@ class_get_property (GObject    *object,
 	case PROP_COUNT:
 		g_value_set_int (value, priv->count);
 		break;
+	case PROP_ID:
+		g_value_set_int (value, priv->id);
+		break;
+	case PROP_IS_NEW:
+		g_value_set_boolean (value, priv->is_new);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
@@ -162,6 +189,14 @@ class_set_property (GObject      *object,
 		tracker_class_set_count (TRACKER_CLASS (object),
 		                         g_value_get_int (value));
 		break;
+	case PROP_ID:
+		tracker_class_set_id (TRACKER_CLASS (object),
+		                      g_value_get_int (value));
+		break;
+	case PROP_IS_NEW:
+		tracker_class_set_is_new (TRACKER_CLASS (object),
+		                             g_value_get_boolean (value));
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
 		break;
@@ -214,6 +249,18 @@ tracker_class_get_count (TrackerClass *service)
 	return priv->count;
 }
 
+gint
+tracker_class_get_id (TrackerClass *service)
+{
+	TrackerClassPriv *priv;
+
+	g_return_val_if_fail (TRACKER_IS_CLASS (service), 0);
+
+	priv = GET_PRIV (service);
+
+	return priv->id;
+}
+
 TrackerClass **
 tracker_class_get_super_classes (TrackerClass *service)
 {
@@ -226,6 +273,18 @@ tracker_class_get_super_classes (TrackerClass *service)
 	return (TrackerClass **) priv->super_classes->data;
 }
 
+gboolean
+tracker_class_get_is_new (TrackerClass *service)
+{
+	TrackerClassPriv *priv;
+
+	g_return_val_if_fail (TRACKER_IS_CLASS (service), FALSE);
+
+	priv = GET_PRIV (service);
+
+	return priv->is_new;
+}
+
 void
 tracker_class_set_uri (TrackerClass *service,
                        const gchar  *value)
@@ -256,7 +315,7 @@ tracker_class_set_uri (TrackerClass *service,
 			g_critical ("Unknown namespace of class %s", priv->uri);
 		} else {
 			namespace_uri = g_strndup (priv->uri, hash - priv->uri + 1);
-			namespace = tracker_ontology_get_namespace_by_uri (namespace_uri);
+			namespace = tracker_ontologies_get_namespace_by_uri (namespace_uri);
 			if (namespace == NULL) {
 				g_critical ("Unknown namespace %s of class %s", namespace_uri, priv->uri);
 			} else {
@@ -282,6 +341,21 @@ tracker_class_set_count (TrackerClass *service,
 	priv->count = value;
 }
 
+
+void
+tracker_class_set_id (TrackerClass *service,
+                      gint          value)
+{
+	TrackerClassPriv *priv;
+
+	g_return_if_fail (TRACKER_IS_CLASS (service));
+
+	priv = GET_PRIV (service);
+
+	priv->id = value;
+}
+
+
 void
 tracker_class_set_super_classes (TrackerClass  *service,
                                  TrackerClass **value)
@@ -315,3 +389,16 @@ tracker_class_add_super_class (TrackerClass *service,
 	g_array_append_val (priv->super_classes, value);
 }
 
+void
+tracker_class_set_is_new (TrackerClass *service,
+                          gboolean         value)
+{
+	TrackerClassPriv *priv;
+
+	g_return_if_fail (TRACKER_IS_CLASS (service));
+
+	priv = GET_PRIV (service);
+
+	priv->is_new = value;
+	g_object_notify (G_OBJECT (service), "is-new");
+}
