@@ -25,7 +25,7 @@
 #include <glib.h>
 
 #include "tracker-namespace.h"
-#include "tracker-ontology.h"
+#include "tracker-ontologies.h"
 #include "tracker-property.h"
 
 #define XSD_BOOLEAN  TRACKER_XSD_PREFIX "boolean"
@@ -50,11 +50,13 @@ struct _TrackerPropertyPriv {
 	gint           id;
 	gboolean       indexed;
 	gboolean       fulltext_indexed;
+	gboolean       fulltext_no_limit;
 	gboolean       embedded;
 	gboolean       multiple_values;
 	gboolean       filtered;
 	gboolean       transient;
 	gboolean       is_inverse_functional_property;
+	gboolean       is_new;
 
 	GArray        *super_properties;
 };
@@ -79,12 +81,14 @@ enum {
 	PROP_WEIGHT,
 	PROP_INDEXED,
 	PROP_FULLTEXT_INDEXED,
+	PROP_FULLTEXT_NO_LIMIT,
 	PROP_EMBEDDED,
 	PROP_MULTIPLE_VALUES,
 	PROP_FILTERED,
 	PROP_TRANSIENT,
 	PROP_IS_INVERSE_FUNCTIONAL_PROPERTY,
-	PROP_ID
+	PROP_ID,
+	PROP_IS_NEW
 };
 
 GType
@@ -224,6 +228,13 @@ tracker_property_class_init (TrackerPropertyClass *klass)
 	                                                       "Full-text indexed",
 	                                                       TRUE,
 	                                                       G_PARAM_READWRITE));
+	g_object_class_install_property (object_class,
+	                                 PROP_FULLTEXT_NO_LIMIT,
+	                                 g_param_spec_boolean ("fulltext-no-limit",
+	                                                       "fulltext-no-limit",
+	                                                       "Full-text indexing without word length limits",
+	                                                       TRUE,
+	                                                       G_PARAM_READWRITE));
 	g_object_class_install_property (object_class,
 	                                 PROP_EMBEDDED,
 	                                 g_param_spec_boolean ("embedded",
@@ -259,6 +270,13 @@ tracker_property_class_init (TrackerPropertyClass *klass)
 	                                                       "Is inverse functional property",
 	                                                       FALSE,
 	                                                       G_PARAM_READWRITE));
+	g_object_class_install_property (object_class,
+	                                 PROP_IS_NEW,
+	                                 g_param_spec_boolean ("is-new",
+	                                                       "is-new",
+	                                                       "Set to TRUE when a new class or property is to be added to the database ontology",
+	                                                       FALSE,
+	                                                       G_PARAM_READWRITE));
 
 
 	g_type_class_add_private (object_class, sizeof (TrackerPropertyPriv));
@@ -341,6 +359,12 @@ property_get_property (GObject    *object,
 	case PROP_FULLTEXT_INDEXED:
 		g_value_set_boolean (value, priv->fulltext_indexed);
 		break;
+	case PROP_FULLTEXT_NO_LIMIT:
+		g_value_set_boolean (value, priv->fulltext_no_limit);
+		break;
+	case PROP_IS_NEW:
+		g_value_set_boolean (value, priv->is_new);
+		break;
 	case PROP_EMBEDDED:
 		g_value_set_boolean (value, priv->embedded);
 		break;
@@ -397,10 +421,18 @@ property_set_property (GObject      *object,
 		tracker_property_set_indexed (TRACKER_PROPERTY (object),
 		                              g_value_get_boolean (value));
 		break;
+	case PROP_IS_NEW:
+		tracker_property_set_is_new (TRACKER_PROPERTY (object),
+		                             g_value_get_boolean (value));
+		break;
 	case PROP_FULLTEXT_INDEXED:
 		tracker_property_set_fulltext_indexed (TRACKER_PROPERTY (object),
 		                                       g_value_get_boolean (value));
 		break;
+	case PROP_FULLTEXT_NO_LIMIT:
+		tracker_property_set_fulltext_no_limit (TRACKER_PROPERTY (object),
+							g_value_get_boolean (value));
+		break;
 	case PROP_EMBEDDED:
 		tracker_property_set_embedded (TRACKER_PROPERTY (object),
 		                               g_value_get_boolean (value));
@@ -577,7 +609,6 @@ tracker_property_get_indexed (TrackerProperty *field)
 	return priv->indexed;
 }
 
-
 gboolean
 tracker_property_get_fulltext_indexed (TrackerProperty *field)
 {
@@ -590,6 +621,29 @@ tracker_property_get_fulltext_indexed (TrackerProperty *field)
 	return priv->fulltext_indexed;
 }
 
+gboolean
+tracker_property_get_fulltext_no_limit (TrackerProperty *field)
+{
+	TrackerPropertyPriv *priv;
+
+	g_return_val_if_fail (TRACKER_IS_PROPERTY (field), FALSE);
+
+	priv = GET_PRIV (field);
+
+	return priv->fulltext_no_limit;
+}
+
+gboolean
+tracker_property_get_is_new (TrackerProperty *field)
+{
+	TrackerPropertyPriv *priv;
+
+	g_return_val_if_fail (TRACKER_IS_PROPERTY (field), FALSE);
+
+	priv = GET_PRIV (field);
+
+	return priv->is_new;
+}
 
 gboolean
 tracker_property_get_embedded (TrackerProperty *field)
@@ -603,7 +657,6 @@ tracker_property_get_embedded (TrackerProperty *field)
 	return priv->embedded;
 }
 
-
 gboolean
 tracker_property_get_multiple_values (TrackerProperty *field)
 {
@@ -682,7 +735,7 @@ tracker_property_set_uri (TrackerProperty *field,
 			g_critical ("Unknown namespace of property %s", priv->uri);
 		} else {
 			namespace_uri = g_strndup (priv->uri, hash - priv->uri + 1);
-			namespace = tracker_ontology_get_namespace_by_uri (namespace_uri);
+			namespace = tracker_ontologies_get_namespace_by_uri (namespace_uri);
 			if (namespace == NULL) {
 				g_critical ("Unknown namespace %s of property %s", namespace_uri, priv->uri);
 			} else {
@@ -829,6 +882,20 @@ tracker_property_set_indexed (TrackerProperty *field,
 	g_object_notify (G_OBJECT (field), "indexed");
 }
 
+void
+tracker_property_set_is_new (TrackerProperty *field,
+                             gboolean         value)
+{
+	TrackerPropertyPriv *priv;
+
+	g_return_if_fail (TRACKER_IS_PROPERTY (field));
+
+	priv = GET_PRIV (field);
+
+	priv->is_new = value;
+	g_object_notify (G_OBJECT (field), "is-new");
+}
+
 void
 tracker_property_set_fulltext_indexed (TrackerProperty *field,
                                        gboolean                 value)
@@ -843,6 +910,20 @@ tracker_property_set_fulltext_indexed (TrackerProperty *field,
 	g_object_notify (G_OBJECT (field), "fulltext-indexed");
 }
 
+void
+tracker_property_set_fulltext_no_limit (TrackerProperty *field,
+                                       gboolean                 value)
+{
+	TrackerPropertyPriv *priv;
+
+	g_return_if_fail (TRACKER_IS_PROPERTY (field));
+
+	priv = GET_PRIV (field);
+
+	priv->fulltext_no_limit = value;
+	g_object_notify (G_OBJECT (field), "fulltext-no-limit");
+}
+
 void
 tracker_property_set_embedded (TrackerProperty *field,
                                gboolean                 value)
