@@ -82,13 +82,13 @@ typedef struct {
 	gchar *city;
 } TrackerXmpData;
 
-gboolean tracker_xmp_read  (const gchar          *buffer,
-                            size_t                len,
-                            const gchar          *uri,
-                            TrackerXmpData       *data);
-gboolean tracker_xmp_apply (TrackerSparqlBuilder *metadata,
-                            const gchar          *uri,
-                            TrackerXmpData       *data);
+gboolean tracker_extract_xmp_read  (const gchar          *buffer,
+                                    size_t                len,
+                                    const gchar          *uri,
+                                    TrackerXmpData       *data);
+gboolean tracker_extract_xmp_apply (TrackerSparqlBuilder *metadata,
+                                    const gchar          *uri,
+                                    TrackerXmpData       *data);
 
 G_END_DECLS
 
