@@ -186,7 +186,8 @@ tracker_miner_manager_class_init (TrackerMinerManagerClass *klass)
 
 static DBusGProxy *
 find_miner_proxy (TrackerMinerManager *manager,
-                  const gchar         *name)
+                  const gchar         *name,
+                  gboolean             try_suffix)
 {
 	TrackerMinerManagerPrivate *priv;
 	GHashTableIter iter;
@@ -199,6 +200,12 @@ find_miner_proxy (TrackerMinerManager *manager,
 		if (g_strcmp0 (name, (gchar *) value) == 0) {
 			return key;
 		}
+
+		if (try_suffix) {
+			if (g_str_has_suffix (value, name)) {
+				return key;
+			}
+		}
 	}
 
 	return NULL;
@@ -216,7 +223,7 @@ name_owner_changed_cb (DBusGProxy  *proxy,
 
 	priv = TRACKER_MINER_MANAGER_GET_PRIVATE (manager);
 
-	if (find_miner_proxy (manager, name) != NULL) {
+	if (find_miner_proxy (manager, name, FALSE) != NULL) {
 		if (new_owner && (!old_owner || !*old_owner)) {
 			g_signal_emit (manager, signals[MINER_ACTIVATED], 0, name);
 		} else if (old_owner && (!new_owner || !*new_owner)) {
@@ -437,9 +444,18 @@ tracker_miner_manager_get_running (TrackerMinerManager *manager)
 
 	if (result) {
 		for (p = result; *p; p++) {
-			if (g_str_has_prefix (*p, TRACKER_MINER_DBUS_NAME_PREFIX)) {
-				list = g_slist_prepend (list, g_strdup (*p));
+			if (!g_str_has_prefix (*p, TRACKER_MINER_DBUS_NAME_PREFIX)) {
+				continue;
 			}
+
+			/* Special case miner-fs which has
+			 * additional D-Bus interface.
+			 */
+			if (strcmp (*p, "org.freedesktop.Tracker1.Miner.Files.Reindex") == 0) {
+				continue;
+			}
+
+			list = g_slist_prepend (list, g_strdup (*p));
 		}
 
 		list = g_slist_reverse (list);
@@ -512,12 +528,7 @@ crawler_check_file_cb (TrackerCrawler *crawler,
 
 static void
 crawler_finished_cb (TrackerCrawler *crawler,
-                     GQueue         *found,
                      gboolean        was_interrupted,
-                     guint           directories_found,
-                     guint           directories_ignored,
-                     guint           files_found,
-                     guint           files_ignored,
                      gpointer        user_data)
 {
 	g_main_loop_quit (user_data);
@@ -604,7 +615,7 @@ tracker_miner_manager_pause (TrackerMinerManager *manager,
 	g_return_val_if_fail (miner != NULL, FALSE);
 	g_return_val_if_fail (reason != NULL, FALSE);
 
-	proxy = find_miner_proxy (manager, miner);
+	proxy = find_miner_proxy (manager, miner, TRUE);
 
 	if (!proxy) {
 		g_critical ("No D-Bus proxy found for miner '%s'", miner);
@@ -654,7 +665,7 @@ tracker_miner_manager_resume (TrackerMinerManager *manager,
 
 	g_return_val_if_fail (TRACKER_IS_MINER_MANAGER (manager), FALSE);
 	g_return_val_if_fail (miner != NULL, FALSE);
-	proxy = find_miner_proxy (manager, miner);
+	proxy = find_miner_proxy (manager, miner, TRUE);
 
 	if (!proxy) {
 		g_critical ("No D-Bus proxy found for miner '%s'", miner);
@@ -733,7 +744,7 @@ tracker_miner_manager_get_status (TrackerMinerManager  *manager,
 	g_return_val_if_fail (TRACKER_IS_MINER_MANAGER (manager), FALSE);
 	g_return_val_if_fail (miner != NULL, FALSE);
 
-	proxy = find_miner_proxy (manager, miner);
+	proxy = find_miner_proxy (manager, miner, TRUE);
 
 	if (!proxy) {
 		g_critical ("No D-Bus proxy found for miner '%s'", miner);
@@ -816,7 +827,7 @@ tracker_miner_manager_is_paused (TrackerMinerManager *manager,
 	g_return_val_if_fail (TRACKER_IS_MINER_MANAGER (manager), TRUE);
 	g_return_val_if_fail (miner != NULL, TRUE);
 
-	proxy = find_miner_proxy (manager, miner);
+	proxy = find_miner_proxy (manager, miner, TRUE);
 
 	if (!proxy) {
 		g_critical ("No D-Bus proxy found for miner '%s'", miner);
@@ -916,19 +927,19 @@ tracker_miner_manager_get_description (TrackerMinerManager *manager,
 
 
 /**
- * tracker_miner_manager_writeback:
+ * tracker_miner_manager_ignore_next_update:
  * @manager: a #TrackerMinerManager.
  * @miner: miner reference
- * @subjects: subjects to mark as writeback
+ * @urls: subjects to mark as writeback
  *
  * Asks @miner to mark @subjects as writeback
  *
- * Returns: %TRUE if the miner was asked to writeback successfully.
+ * Returns: %TRUE if the miner was asked to ignore on next update successfully.
  **/
 gboolean
-tracker_miner_manager_writeback (TrackerMinerManager *manager,
-                                 const gchar         *miner,
-                                 const gchar        **subjects)
+tracker_miner_manager_ignore_next_update (TrackerMinerManager *manager,
+                                          const gchar         *miner,
+                                          const gchar        **urls)
 {
 	DBusGProxy *proxy;
 	const gchar *app_name;
@@ -937,7 +948,7 @@ tracker_miner_manager_writeback (TrackerMinerManager *manager,
 	g_return_val_if_fail (TRACKER_IS_MINER_MANAGER (manager), FALSE);
 	g_return_val_if_fail (miner != NULL, FALSE);
 
-	proxy = find_miner_proxy (manager, miner);
+	proxy = find_miner_proxy (manager, miner, TRUE);
 
 	if (!proxy) {
 		g_warning ("No D-Bus proxy found for miner '%s'", miner);
@@ -955,10 +966,10 @@ tracker_miner_manager_writeback (TrackerMinerManager *manager,
 		app_name = "TrackerMinerManager client";
 	}
 
-	org_freedesktop_Tracker1_Miner_writeback (proxy, subjects, &error);
+	org_freedesktop_Tracker1_Miner_ignore_next_update (proxy, urls, &error);
 
 	if (error) {
-		g_warning ("Could not writeback miner '%s': %s", miner, error->message);
+		g_warning ("Could not ignore next update for miner '%s': %s", miner, error->message);
 		g_error_free (error);
 		return FALSE;
 	}
