@@ -266,10 +266,10 @@ add_fraction_gst_tag (TrackerSparqlBuilder         *metadata,
 
 	ret = gst_tag_list_copy_value (&n, tag_list, tag);
 
-	f = (gfloat)gst_value_get_fraction_numerator (&n)/
+	if (ret) {
+		f = (gfloat)gst_value_get_fraction_numerator (&n)/
 		gst_value_get_fraction_denominator (&n);
 
-	if (ret) {
 		tracker_sparql_builder_predicate (metadata, key);
 		tracker_sparql_builder_object_double (metadata, (gdouble) f);
 	}
@@ -288,6 +288,16 @@ add_y_date_gst_tag (TrackerSparqlBuilder  *metadata,
 	date = NULL;
 	ret = gst_tag_list_get_date (tag_list, tag, &date);
 
+	if (ret) {
+		if (date && g_date_valid (date)) {
+			if (date->julian)
+				ret = g_date_valid_julian (date->julian_days);
+			if (date->dmy)
+				ret = g_date_valid_dmy (date->day, date->month, date->year);
+		} else
+			ret = FALSE;
+	}
+
 	if (ret) {
 		gchar buf[25];
 
@@ -748,6 +758,22 @@ extract_metadata (MetadataExtractor      *extractor,
 		g_free (album_uri);
 
 		add_string_gst_tag (metadata, uri, "nfo:codec", extractor->tagcache, GST_TAG_AUDIO_CODEC);
+	} else {
+		if (extractor->mime == EXTRACT_MIME_AUDIO)
+			needs_audio = TRUE;
+
+		tracker_sparql_builder_predicate (metadata, "a");
+
+		if (needs_audio) {
+			tracker_sparql_builder_object (metadata, "nmm:MusicPiece");
+			tracker_sparql_builder_object (metadata, "nfo:Audio");
+		} 
+
+		if (extractor->mime == EXTRACT_MIME_VIDEO) {
+			tracker_sparql_builder_object (metadata, "nmm:Video");
+		} else if (!needs_audio) {
+			tracker_sparql_builder_object (metadata, "nfo:Image");
+		}
 	}
 
 
