@@ -37,7 +37,7 @@
 #include <glib/gstdio.h>
 
 #include <libtracker-common/tracker-date-time.h>
-#include <libtracker-common/tracker-ontology.h>
+#include <libtracker-common/tracker-ontologies.h>
 #include <libtracker-common/tracker-type-utils.h>
 #include <libtracker-common/tracker-file-utils.h>
 #include <libtracker-common/tracker-utils.h>
@@ -98,7 +98,7 @@ rfc1123_to_iso8601_date (gchar *date)
 	/* From: ex. RFC1123 date: "22 May 1997 18:07:10 -0600"
 	 * To  : ex. ISO8601 date: "2007-05-22T18:07:10-0600"
 	 */
-	return tracker_date_format_to_iso8601 (date, RFC1123_DATE_FORMAT);
+	return tracker_extract_date_format_to_iso8601 (date, RFC1123_DATE_FORMAT);
 }
 
 static void
