@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2009, Nokia (urho.konttori@nokia.com)
  *
@@ -28,7 +27,7 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
-#include <panel-applet-gconf.h>
+#include <panel-applet.h>
 
 #include <libtracker-client/tracker.h>
 
@@ -40,9 +39,10 @@
 
 #define MUSIC_QUERY	  \
 	"SELECT" \
-	"  ?urn ?title ?tooltip ?urn fts:rank(?urn) " \
+	"  ?uri ?title ?tooltip ?uri fts:rank(?urn) " \
 	"WHERE {" \
 	"  ?urn a nfo:Audio ;" \
+	"  nie:url ?uri ; " \
 	"  nfo:fileName ?title ;" \
 	"  nfo:belongsToContainer ?tooltip ." \
 	"  ?urn fts:match \"%s*\" " \
@@ -51,9 +51,10 @@
 	"OFFSET 0 LIMIT %d"
 #define IMAGE_QUERY	  \
 	"SELECT" \
-	"  ?urn ?title ?tooltip ?urn fts:rank(?urn) " \
+	"  ?uri ?title ?tooltip ?uri fts:rank(?urn) " \
 	"WHERE {" \
 	"  ?urn a nfo:Image ;" \
+	"  nie:url ?uri ; " \
 	"  nfo:fileName ?title ;" \
 	"  nfo:belongsToContainer ?tooltip ." \
 	"  ?urn fts:match \"%s*\" " \
@@ -62,9 +63,10 @@
 	"OFFSET 0 LIMIT %d"
 #define VIDEO_QUERY	  \
 	"SELECT" \
-	"  ?urn ?title ?tooltip ?urn fts:rank(?urn) " \
+	"  ?uri ?title ?tooltip ?uri fts:rank(?urn) " \
 	"WHERE {" \
 	"  ?urn a nmm:Video ;" \
+	"  nie:url ?uri ; " \
 	"  nfo:fileName ?title ;" \
 	"  nfo:belongsToContainer ?tooltip ." \
 	"  ?urn fts:match \"%s*\" " \
@@ -73,9 +75,10 @@
 	"OFFSET 0 LIMIT %d"
 #define DOCUMENT_QUERY	  \
 	"SELECT" \
-	"  ?urn ?title ?tooltip ?urn fts:rank(?urn) " \
+	"  ?uri ?title ?tooltip ?uri fts:rank(?urn) " \
 	"WHERE {" \
 	"  ?urn a nfo:Document ;" \
+	"  nie:url ?uri ; " \
 	"  nfo:fileName ?title ;" \
 	"  nfo:belongsToContainer ?tooltip ." \
 	"  ?urn fts:match \"%s*\" " \
@@ -84,9 +87,10 @@
 	"OFFSET 0 LIMIT %d"
 #define FOLDER_QUERY	  \
 	"SELECT" \
-	"  ?urn ?title ?tooltip ?urn fts:rank(?urn) " \
+	"  ?uri ?title ?tooltip ?uri fts:rank(?urn) " \
 	"WHERE {" \
 	"  ?urn a nfo:Folder ;" \
+	"  nie:url ?uri ; " \
 	"  nfo:fileName ?title ;" \
 	"  nfo:belongsToContainer ?tooltip ." \
 	"  ?urn fts:match \"%s*\" " \
@@ -381,7 +385,7 @@ tracker_results_window_init (TrackerResultsWindow *window)
 
 	priv = TRACKER_RESULTS_WINDOW_GET_PRIVATE (window);
 
-	priv->client = tracker_connect (FALSE, G_MAXINT);
+	priv->client = tracker_client_new (TRACKER_CLIENT_ENABLE_WARNINGS, G_MAXINT);
 
 	priv->frame = gtk_frame_new (NULL);
 	gtk_container_add (GTK_CONTAINER (window), priv->frame);
@@ -437,7 +441,7 @@ results_window_finalize (GObject *object)
 	g_free (priv->query);
 
 	if (priv->client) {
-		tracker_disconnect (priv->client);
+		g_object_unref (priv->client);
 	}
 
 	G_OBJECT_CLASS (tracker_results_window_parent_class)->finalize (object);
@@ -721,8 +725,8 @@ category_from_string (const gchar *type,
 
 static GdkPixbuf *
 pixbuf_get (TrackerResultsWindow *window,
-            const gchar          *urn,
-            gboolean              is_image)
+            const gchar          *uri,
+            TrackerCategory       category)
 {
 	TrackerResultsWindowPrivate *priv;
 	const gchar *attributes;
@@ -733,9 +737,9 @@ pixbuf_get (TrackerResultsWindow *window,
 	GError *error = NULL;
 
 	priv = TRACKER_RESULTS_WINDOW_GET_PRIVATE (window);
-	file = g_file_new_for_uri (urn);
+	file = g_file_new_for_uri (uri);
 
-	if (is_image) {
+	if (category & CATEGORY_IMAGE) {
 		gchar *path;
 
 		path = g_file_get_path (file);
@@ -743,58 +747,64 @@ pixbuf_get (TrackerResultsWindow *window,
 		g_free (path);
 
 		if (error) {
-			g_printerr ("Couldn't get pixbuf for urn:'%s', %s\n",
-			            urn,
+			g_printerr ("Couldn't get pixbuf for uri:'%s', %s\n",
+			            uri,
 			            error->message);
 			g_clear_error (&error);
 		} else {
 			g_object_unref (file);
 			return pixbuf;
 		}
+	} else if (category &
+		   (CATEGORY_DOCUMENT |
+		    CATEGORY_IMAGE |
+		    CATEGORY_AUDIO |
+		    CATEGORY_FOLDER |
+		    CATEGORY_VIDEO |
+		    CATEGORY_ARCHIVE)) {
+		attributes =
+			G_FILE_ATTRIBUTE_STANDARD_ICON;
 
-		/* In event of failure, get generic icon */
-	}
+		info = g_file_query_info (file,
+		                          attributes,
+		                          G_FILE_QUERY_INFO_NONE,
+		                          NULL,
+		                          &error);
 
+		if (error) {
+			g_printerr ("Couldn't get pixbuf for uri:'%s', %s\n",
+			            uri,
+			            error->message);
+			g_object_unref (file);
+			g_error_free (error);
 
-	attributes =
-		G_FILE_ATTRIBUTE_STANDARD_ICON;
-
-	info = g_file_query_info (file,
-	                          attributes,
-	                          G_FILE_QUERY_INFO_NONE,
-	                          NULL,
-	                          &error);
-
-
-	if (error) {
-		g_printerr ("Couldn't get pixbuf for urn:'%s', %s\n",
-		            urn,
-		            error->message);
-		g_object_unref (file);
-		g_error_free (error);
-
-		return NULL;
-	}
-
-	icon = g_file_info_get_icon (info);
-
-	if (icon && G_IS_THEMED_ICON (icon)) {
-		GtkIconInfo *icon_info;
-		const gchar **names;
-
-		names = (const gchar**) g_themed_icon_get_names (G_THEMED_ICON (icon));
-		icon_info = gtk_icon_theme_choose_icon (priv->icon_theme,
-		                                        names,
-		                                        24,
-		                                        GTK_ICON_LOOKUP_USE_BUILTIN);
-
-		if (icon_info) {
-			pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
-			gtk_icon_info_free (icon_info);
+			return NULL;
 		}
+
+		icon = g_file_info_get_icon (info);
+
+		if (icon && G_IS_THEMED_ICON (icon)) {
+			GtkIconInfo *icon_info;
+			const gchar **names;
+
+			names = (const gchar**) g_themed_icon_get_names (G_THEMED_ICON (icon));
+			icon_info = gtk_icon_theme_choose_icon (priv->icon_theme,
+			                                        names,
+			                                        24,
+			                                        GTK_ICON_LOOKUP_USE_BUILTIN);
+
+			if (icon_info) {
+				pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
+				gtk_icon_info_free (icon_info);
+			}
+		}
+
+		g_object_unref (info);
+	} else {
+		g_message ("No pixbuf could be retrieved for category %s (URI: %s)\n",
+		           category_to_string (category), uri);
 	}
 
-	g_object_unref (info);
 	g_object_unref (file);
 
 	return pixbuf;
