@@ -85,7 +85,7 @@ static GOptionEntry entries[] = {
 	},
 	{ G_OPTION_REMAINING, 0,
 	  G_OPTION_FLAG_FILENAME,
-	  G_OPTION_ARG_STRING_ARRAY, &files,
+	  G_OPTION_ARG_FILENAME_ARRAY, &files,
 	  N_("FILE…"),
 	  N_("FILE [FILE…]")},
 	{ NULL }
@@ -148,7 +148,8 @@ get_escaped_sparql_string (const gchar *str)
 static gchar *
 get_fts_string (GStrv    search_words,
                 gboolean use_or_operator,
-                gboolean for_regex)
+                gboolean for_regex,
+                gboolean use_asterisk)
 {
 	GString *fts;
 	gint i, len;
@@ -162,7 +163,10 @@ get_fts_string (GStrv    search_words,
 
 	for (i = 0; i < len; i++) {
 		g_string_append (fts, search_words[i]);
-		g_string_append_c (fts, '*');
+
+                if (use_asterisk) {
+                        g_string_append_c (fts, '*');
+                }
 
 		if (i < len - 1) {
 			if (for_regex) {
@@ -313,7 +317,7 @@ get_all_tags (TrackerClient *client,
 	gchar *fts;
 	gchar *query;
 
-	fts = get_fts_string (files, use_or_operator, TRUE);
+	fts = get_fts_string (files, use_or_operator, TRUE, FALSE);
 
 	if (fts) {
 		query = g_strdup_printf ("SELECT ?tag ?label COUNT(?urns) AS urns "
@@ -323,7 +327,7 @@ get_all_tags (TrackerClient *client,
 		                         "  OPTIONAL {"
 		                         "     ?urns nao:hasTag ?tag"
 		                         "  } ."
-		                         "  FILTER regex (?label, \"%s\")"
+		                         "  FILTER (?label = \"%s\")"
 		                         "} "
 		                         "GROUP BY ?tag "
 		                         "ORDER BY ASC(?label) "
@@ -527,23 +531,9 @@ remove_tag_for_urns (TrackerClient *client,
 		                         "}",
 		                         filter);
 		g_free (filter);
-#if 0
-		filter = get_filter_string (files);
-
-		query = g_strdup_printf ("DELETE {"
-		                         "  <%s> nao:hasTag ?tag "
-		                         "} "
-		                         "WHERE {"
-		                         "  <%s> nao:hasTag ?tag"
-		                         "  FILTER (?tag = <%s>)"
-		                         "}",
-		                         files[0],
-		                         files[0],
-		                         urn);
 
 		g_ptr_array_foreach (results, (GFunc) g_strfreev, NULL);
 		g_ptr_array_free (results, TRUE);
-#endif
 	} else {
 		/* Remove tag completely */
 		query = g_strdup_printf ("DELETE { "
@@ -586,7 +576,7 @@ get_tags_by_file_foreach (gpointer value,
 
 static gboolean
 get_tags_by_file (TrackerClient *client,
-                  const gchar   *file)
+                  const gchar   *uri)
 {
 	GError *error = NULL;
 	GPtrArray *results;
@@ -594,13 +584,13 @@ get_tags_by_file (TrackerClient *client,
 
 	query = g_strdup_printf ("SELECT ?tags ?labels "
 	                         "WHERE {"
-	                         "  <%s>"
-	                         "  nao:hasTag ?tags ."
+	                         "  ?urn nao:hasTag ?tags ;"
+	                         "  nie:url <%s> ."
 	                         "  ?tags a nao:Tag ;"
 	                         "  nao:prefLabel ?labels "
 	                         "} "
 	                         "ORDER BY ASC(?labels)",
-	                         file);
+	                         uri);
 
 	results = tracker_resources_sparql_query (client, query, &error);
 	g_free (query);
@@ -723,9 +713,18 @@ main (int argc, char **argv)
 		gchar **p;
 
 		for (p = files; *p; p++) {
-			g_print ("<%s>\n", *p);
-			success &= get_tags_by_file (client, *p);
+			GFile *file;
+			gchar *uri;
+			
+			file = g_file_new_for_commandline_arg (*p);
+			uri = g_file_get_uri (file);
+			g_object_unref (file);
+
+			g_print ("%s\n", uri);
+			success &= get_tags_by_file (client, uri);
 			g_print ("\n");
+
+			g_free (uri);
 		}
 
 		g_object_unref (client);
